@@ -192,7 +192,7 @@ def pter_upload(web,file1,record_path,qbinfo):
         logger.warning('选择匿名发布发生错误，错误信息: %s' %(r))
 
 
-    #a=input('check')
+    a=input('check')
     String_url = web.driver.current_url;
     try:
         web.driver.find_elements(By.ID,'qr')[0].click()
@@ -207,7 +207,7 @@ def pter_upload(web,file1,record_path,qbinfo):
     downloadurl=finddownloadurl(driver=web.driver,elementstr='/html/body/table[2]/tbody/tr[2]/td/table[1]/tbody/tr[9]/td[2]/a')
     if downloadurl=='已存在':
         return True,fileinfo+'种子发布失败,失败原因:种子'+downloadurl+',当前网址:'+web.driver.current_url
-    #a=input('check')
+    a=input('check')
     
     recordupload(os.path.join(record_path,web.site.sitename+'_torrent.csv'),file1,String_url,downloadurl)
     if not downloadurl =='':
